"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.importOpenApi = void 0;
const set_1 = __importDefault(require("lodash/set"));
const generateHooks_1 = require("./generateHooks");
const generateImports_1 = require("./generateImports");
const getResReqTypes_1 = require("./getResReqTypes");
/**
 * Propagate every `discriminator.propertyName` mapping to the original ref
 *
 * Note: This method directly mutate the `specs` object.
 */
const resolveDiscriminator = (specs) => {
    if (specs.components && specs.components.schemas) {
        Object.values(specs.components.schemas).forEach((schema) => {
            if ((0, getResReqTypes_1.isReference)(schema) || !schema.discriminator || !schema.discriminator.mapping) {
                return;
            }
            const { mapping, propertyName } = schema.discriminator;
            Object.entries(mapping).forEach(([name, ref]) => {
                if (!ref.startsWith('#/components/schemas/')) {
                    throw new Error('Discriminator mapping outside of `#/components/schemas` is not supported');
                }
                (0, set_1.default)(specs, `components.schemas.${ref.slice('#/components/schemas/'.length)}.properties.${propertyName}.enum`, [name]);
            });
        });
    }
};
const importOpenApi = async ({ specs, apiDirectory, queryClientDir, headerFilters = [], }) => {
    const operationIds = [];
    resolveDiscriminator(specs);
    const imports = (0, generateImports_1.generateImports)({ apiDirectory, queryClientDir });
    const hooks = (0, generateHooks_1.generateQueryHooks)(specs, operationIds, headerFilters);
    return imports + hooks;
};
exports.importOpenApi = importOpenApi;
