"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.importSpecs = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = require("fs");
const path_1 = require("path");
const convertSwaggerFile_1 = require("./convertSwaggerFile");
const generateHooks_1 = require("./generateHooks");
const generateSchemas_1 = require("./generateSchemas");
function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, }) {
    (0, fs_1.readdir)(sourceDirectory, function (err, filenames) {
        if (err) {
            console.log(err);
            throw err;
        }
        filenames.map(async (filename) => {
            const data = (0, fs_1.readFileSync)((0, path_1.join)(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
            const { ext } = (0, path_1.parse)(sourceDirectory + '/' + filename);
            const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
            try {
                const name = filename.split('.')[0];
                const hooksName = `useQueries${filename.split('.')[0]}`;
                const schemaName = `useQueries${filename.split('.')[0]}.schema`;
                let spec = await (0, convertSwaggerFile_1.convertSwaggerFile)(data, format);
                const operationIds = [];
                (0, fs_1.mkdirSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}`), { recursive: true });
                const hooks = (0, generateHooks_1.generateQueryHooks)({
                    spec,
                    schemaName,
                    operationIds,
                    headerFilters,
                    apiDirectory,
                    queryClientDir,
                });
                (0, fs_1.writeFileSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}/${hooksName}.tsx`), hooks);
                const schemas = (0, generateSchemas_1.generateSchemas)(spec);
                (0, fs_1.writeFileSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}/${schemaName}.tsx`), schemas);
                console.log(chalk_1.default.green(`🎉 [${filename}] Your OpenAPI spec has been converted into react query hooks`));
            }
            catch (error) {
                console.log(chalk_1.default.red(`[${filename}]:`), chalk_1.default.red(error));
            }
        });
    });
}
exports.importSpecs = importSpecs;
