import { pascal } from 'case';
import isEmpty from 'lodash/isEmpty';
import { formatDescription, getScalar, isReference, resolveValue } from './getResReqTypes';
/**
 * Generate the interface string
 */
const generateInterface = (name, schema) => {
    const scalar = getScalar(schema);
    return `
       ${formatDescription(schema.description)}
       export type ${pascal(name)} = ${scalar}
     `;
};
/**
 * Extract all types from #/components/schemas
 */
export const generateSchemasDefinition = (schemas = {}) => {
    if (isEmpty(schemas)) {
        return '';
    }
    return ('\n // SCEHMAS' +
        Object.entries(schemas)
            .map(([name, schema]) => !isReference(schema) &&
            (!schema.type || schema.type === 'object') &&
            !schema.allOf &&
            !schema.oneOf &&
            !isReference(schema) &&
            !schema.nullable
            ? generateInterface(name, schema)
            : `${formatDescription(isReference(schema) ? undefined : schema.description)} type ${pascal(name)} = ${resolveValue(schema)};`)
            .join('\n\n') +
        '\n');
};
