import set from 'lodash/set';
import { generateQueryHooks } from './generateHooks';
import { generateImports } from './generateImports';
import { isReference } from './getResReqTypes';
/**
 * Propagate every `discriminator.propertyName` mapping to the original ref
 *
 * Note: This method directly mutate the `specs` object.
 */
const resolveDiscriminator = (specs) => {
    if (specs.components && specs.components.schemas) {
        Object.values(specs.components.schemas).forEach((schema) => {
            if (isReference(schema) || !schema.discriminator || !schema.discriminator.mapping) {
                return;
            }
            const { mapping, propertyName } = schema.discriminator;
            Object.entries(mapping).forEach(([name, ref]) => {
                if (!ref.startsWith('#/components/schemas/')) {
                    throw new Error('Discriminator mapping outside of `#/components/schemas` is not supported');
                }
                set(specs, `components.schemas.${ref.slice('#/components/schemas/'.length)}.properties.${propertyName}.enum`, [name]);
            });
        });
    }
};
export const importOpenApi = async ({ specs, apiDirectory, queryClientDir, headerFilters = [], }) => {
    const operationIds = [];
    resolveDiscriminator(specs);
    const imports = generateImports({ apiDirectory, queryClientDir });
    const hooks = generateQueryHooks(specs, operationIds, headerFilters);
    return imports + hooks;
};
