import chalk from 'chalk';
import { readFileSync, writeFileSync, readdir, mkdirSync } from 'fs';
import { join, parse } from 'path';
import { convertSwaggerFile } from './convertSwaggerFile';
import { generateQueryHooks } from './generateHooks';
import { generateSchemas } from './generateSchemas';
export function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, }) {
    readdir(sourceDirectory, function (err, filenames) {
        if (err) {
            console.log(err);
            throw err;
        }
        filenames.map(async (filename) => {
            const data = readFileSync(join(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
            const { ext } = parse(sourceDirectory + '/' + filename);
            const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
            try {
                const name = filename.split('.')[0];
                const hooksName = `useQueries${filename.split('.')[0]}`;
                const schemaName = `useQueries${filename.split('.')[0]}.schema`;
                let spec = await convertSwaggerFile(data, format);
                const operationIds = [];
                mkdirSync(join(process.cwd(), `${exportDirectory}/${name}`), { recursive: true });
                const hooks = generateQueryHooks({
                    spec,
                    schemaName,
                    operationIds,
                    headerFilters,
                    apiDirectory,
                    queryClientDir,
                });
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${hooksName}.tsx`), hooks);
                const schemas = generateSchemas(spec);
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${schemaName}.tsx`), schemas);
                console.log(chalk.green(`🎉 [${filename}] Your OpenAPI spec has been converted into react query hooks`));
            }
            catch (error) {
                console.log(chalk.red(`[${filename}]:`), chalk.red(error));
            }
        });
    });
}
