import set from 'lodash/set';
import { isReference } from './getResReqTypes';
/**
 * Propagate every `discriminator.propertyName` mapping to the original ref
 *
 * Note: This method directly mutate the `specs` object.
 */
export const resolveDiscriminator = (specs) => {
    if (specs.components && specs.components.schemas) {
        Object.values(specs.components.schemas).forEach((schema) => {
            if (isReference(schema) || !schema.discriminator || !schema.discriminator.mapping) {
                return;
            }
            const { mapping, propertyName } = schema.discriminator;
            Object.entries(mapping).forEach(([name, ref]) => {
                if (!ref.startsWith('#/components/schemas/')) {
                    throw new Error('Discriminator mapping outside of `#/components/schemas` is not supported');
                }
                console.log('HELLO');
                set(specs, `components.schemas.${ref.slice('#/components/schemas/'.length)}.properties.${propertyName}.enum`, [name]);
            });
        });
    }
};
